import argparse
import json
from eapdataset import Dataset
import pandas as pd
from pathlib import Path

parser = argparse.ArgumentParser()
parser.add_argument("--predictions", type=str, required=True)
parser.add_argument("--data", type=str, required=True)
parser.add_argument("--threshold", type=float, required=True)
parser.add_argument("--enable_alert", type=str, required=True)

parser.add_argument("--result", type=str, required=True)
parser.add_argument("--content", type=str, required=True)
parser.add_argument("--alert", type=str, required=True)


args = parser.parse_args()
df = pd.read_csv(args.data)
df_date = pd.to_datetime(df['data_time_utc'])
df_date = df_date + pd.DateOffset(minutes=20)

with open(args.predictions, 'r') as f:
    predictions = json.load(f)
    is_abnormal = [1 if p >= args.threshold else 0 for p in predictions]
    result_df = pd.DataFrame({
            'data_time_utc': df_date.tolist(),
            'predicted': predictions,
            'threshold': [args.threshold] * 2,
            'is_abnormal': is_abnormal
        })

    Path(args.result).parent.mkdir(parents=True, exist_ok=True)
    result_df.to_csv(args.result, index=False, header=False)
    
    content = ""
    for idx, alert in enumerate(is_abnormal):
        if alert:
            content += f"Abnormality detected {predictions[idx]} at {df_date[idx]} <br>"
            
    Path(args.content).parent.mkdir(parents=True, exist_ok=True)
    with open(args.content, 'w') as af:
        af.write(content)
        
    Path(args.alert).parent.mkdir(parents=True, exist_ok=True)
    with open(args.alert, 'w') as af:
        af.write("true" if content and args.enable_alert == "true" else "false")
    